==> fap-0.9.0.tar.bz2: fap-0.9.0/src/audio/input/ffmpegBackend.h <==
/*
 *  Copyright (C) 2006-2011 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef FFMPEG_H
#define FFMPEG_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

extern "C" {
#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
#  include <libavformat/avformat.h>
#  if LIBAVFORMAT_VERSION_INT > (52<<16 | 31<<8)
#    define HAVE_FFMPEG
#  endif
#endif
}

#ifdef HAVE_FFMPEG

#include "inputBackend.h"
#include "AutoDLL.h"

#include <fx.h>

/*****************************************************************/

#include "configFrame.h"

class ffmpegConfig : public configFrame {
	FXDECLARE(ffmpegConfig)

private:
	ffmpegConfig() {};
	ffmpegConfig(const ffmpegConfig&);
	ffmpegConfig& operator=(const ffmpegConfig&);

public:
	ffmpegConfig(FXPacker* win);
	virtual ~ffmpegConfig() {};
};

/*****************************************************************/

class ffmpegBackend : public inputBackend {

private:
	AVStream	*_audioStream;
	AVFormatContext	*_formatContext;
	int		_audioStreamIndex;
	FXuint		_decodeBufOffset;
	FXuchar		_decodeBuf[AVCODEC_MAX_AUDIO_FRAME_SIZE*2];
	AVPacket	_packet;
	FXuint		_packetOffset;

	static const AutoDLL	_avformat;
	static const AutoDLL	_avcodec;

	static FXString		_ext;

private:
	static int (*dl_av_open_input_file)(AVFormatContext**, const char*, AVInputFormat*, int, AVFormatParameters*);
	static void (*dl_av_close_input_file)(AVFormatContext*);
	static int (*dl_av_find_stream_info)(AVFormatContext*);
	static int (*dl_av_read_frame)(AVFormatContext*, AVPacket*);
	static int (*dl_av_seek_frame)(AVFormatContext*, int, int64_t, int);
	static AVMetadataTag* (*dl_av_metadata_get)(AVMetadata*, const char*, const AVMetadataTag*, int);
	static AVCodec* (*dl_avcodec_find_decoder)(enum CodecID);
	static int (*dl_avcodec_open)(AVCodecContext*, AVCodec*);
	static int (*dl_avcodec_decode_audio3)(AVCodecContext*, int16_t*, int*, AVPacket*);
	static void (*dl_av_init_packet)(AVPacket*);
	static void (*dl_avcodec_flush_buffers)(AVCodecContext*);
	static int (*dl_avcodec_close)(AVCodecContext*);
	static void (*dl_av_free_packet)(AVPacket*);
	//static int64_t (*dl_av_rescale_q)(int64_t, AVRational, AVRational);

private:
	ffmpegBackend();

	/// Open selected stream
	bool openStream(AVFormatContext* fc, const int streamIndex);

	const char* getMetadata(const char* type);

public:
	~ffmpegBackend();

	static const char name[];

	static bool init();

	/// Factory method
	static input* factory() { return new ffmpegBackend(); }

	/// Check if we support ext
	static bool supports(const char* fileName);

	/// Get supported extension
	FXString ext() const;

	/// Open file
	bool open(const FXString& fileName);

	/// Close file
	void close();

	/// Seek specified position
	bool seek(const int pos);

	/// Get samplerate
	unsigned int samplerate() const {
		return _audioStream?
			_audioStream->codec->sample_rate:
			0;
	}

	/// Get channels
	unsigned int channels() const {
		return _audioStream?
			_audioStream->codec->channels:
			0;
	}

	/// Get precision
	sample_t precision() const { return S16; }

	/// Callback function
	size_t fillBuffer(void* buffer, const size_t bufferSize, const unsigned int seconds);

	/// Open config dialog
	void config(FXPacker* win) { new ffmpegConfig(win); }
};

#endif

#endif

==> fap-0.9.2.tar.bz2: fap-0.9.2/src/audio/input/ffmpegBackend.h <==
/*
 *  Copyright (C) 2006-2012 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef FFMPEG_H
#define FFMPEG_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

extern "C" {
#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
#  include <libavformat/avformat.h>
#  if LIBAVFORMAT_VERSION_INT > (52<<16 | 31<<8)
#    define HAVE_FFMPEG
#  endif
#endif
}

#ifdef HAVE_FFMPEG

#include "inputBackend.h"
#include "AutoDLL.h"

#include <fx.h>

/*****************************************************************/

#include "configFrame.h"

class ffmpegConfig : public configFrame {
	FXDECLARE(ffmpegConfig)

private:
	ffmpegConfig() {};
	ffmpegConfig(const ffmpegConfig&);
	ffmpegConfig& operator=(const ffmpegConfig&);

public:
	ffmpegConfig(FXPacker* win);
	virtual ~ffmpegConfig() {};
};

/*****************************************************************/

class ffmpegBackend : public inputBackend {

private:
	AVStream	*_audioStream;
	AVFormatContext	*_formatContext;
	int		_audioStreamIndex;
	FXuint		_decodeBufOffset;
	FXuchar		_decodeBuf[AVCODEC_MAX_AUDIO_FRAME_SIZE*2];
	AVPacket	_packet;
	int		_packetOffset;
	sample_t	_precision;

	static const AutoDLL	_avformat;
	static const AutoDLL	_avcodec;
	static const AutoDLL	_avutil;

	static FXString		_ext;

private:
	static int (*dl_av_open_input_file)(AVFormatContext**, const char*, AVInputFormat*, int, AVFormatParameters*);
	static void (*dl_av_close_input_file)(AVFormatContext*);
	static int (*dl_av_find_stream_info)(AVFormatContext*);
	static int (*dl_av_read_frame)(AVFormatContext*, AVPacket*);
	static int (*dl_av_seek_frame)(AVFormatContext*, int, int64_t, int);
	static AVDictionaryEntry* (*dl_av_dict_get)(AVDictionary*, const char*, const AVDictionaryEntry*, int);
	static AVCodec* (*dl_avcodec_find_decoder)(enum CodecID);
	static int (*dl_avcodec_open)(AVCodecContext*, AVCodec*);
	static int (*dl_avcodec_decode_audio3)(AVCodecContext*, int16_t*, int*, AVPacket*);
	static void (*dl_av_init_packet)(AVPacket*);
	static void (*dl_avcodec_flush_buffers)(AVCodecContext*);
	static int (*dl_avcodec_close)(AVCodecContext*);
	static void (*dl_av_free_packet)(AVPacket*);
	//static int64_t (*dl_av_rescale_q)(int64_t, AVRational, AVRational);

private:
	ffmpegBackend();

	/// Open selected stream
	bool openStream(AVFormatContext* fc, const int streamIndex);

	const char* getMetadata(const char* type);

public:
	~ffmpegBackend();

	static const char name[];

	static bool init();

	/// Factory method
	static input* factory() { return new ffmpegBackend(); }

	/// Check if we support ext
	static bool supports(const char* fileName);

	/// Get supported extension
	FXString ext() const;

	/// Open file
	bool open(const FXString& fileName);

	/// Close file
	void close();

	/// Seek specified position
	bool seek(const int pos);

	/// Get samplerate
	unsigned int samplerate() const {
		return _audioStream?
			_audioStream->codec->sample_rate:
			0;
	}

	/// Get channels
	unsigned int channels() const {
		return _audioStream?
			_audioStream->codec->channels:
			0;
	}

	/// Get precision
	sample_t precision() const { return _precision; }

	/// Callback function
	size_t fillBuffer(void* buffer, const size_t bufferSize, const unsigned int seconds);

	/// Open config dialog
	void config(FXPacker* win) { new ffmpegConfig(win); }
};

#endif

#endif
